# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ghome_foyer_api/api.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""

from __future__ import annotations

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 29, 0, "", "ghome_foyer_api/api.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19ghome_foyer_api/api.proto\x12\x1dgoogle.internal.home.foyer.v1"\x1d\n\x1bGetAssistantRoutinesRequest"\xf4\x06\n\x1cGetAssistantRoutinesResponse\x12M\n\x02p1\x18\x01 \x03(\x0b\x32\x41.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part1\x12M\n\x02p2\x18\x02 \x01(\x0b\x32\x41.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part2\x1a\x8a\x05\n\x05Part1\x12\x14\n\x0croutine_name\x18\x01 \x01(\t\x12\\\n\x08workflow\x18\x03 \x01(\x0b\x32J.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part1.WorkFlow\x12\x0f\n\x07string4\x18\x04 \x01(\t\x12\x0f\n\x07string5\x18\x05 \x01(\t\x1a\xea\x03\n\x08WorkFlow\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x61\n\x05wf_s1\x18\x02 \x01(\x0b\x32R.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1\x1a\xec\x02\n\x07WF_Sub1\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12q\n\x08wf_s1_s1\x18\x02 \x01(\x0b\x32_.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1.WF_Sub1_Sub1\x1a\xdc\x01\n\x0cWF_Sub1_Sub1\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12x\n\x07routine\x18\x02 \x01(\x0b\x32g.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1.WF_Sub1_Sub1.Routine\x1a\x41\n\x07Routine\x12\x12\n\nroutine_id\x18\x01 \x01(\t\x12\x0c\n\x04num2\x18\x02 \x01(\r\x12\x14\n\x0croutine_name\x18\x03 \x01(\t\x1a)\n\x05Part2\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12\x0f\n\x07string3\x18\x03 \x01(\t"4\n\x13GetHomeGraphRequest\x12\x0f\n\x07string1\x18\x03 \x01(\t\x12\x0c\n\x04num2\x18\x04 \x01(\t"\xbc\x37\n\x14GetHomeGraphResponse\x12\x12\n\ntimestamp1\x18\x01 \x01(\x04\x12\x46\n\x04home\x18\x02 \x01(\x0b\x32\x38.google.internal.home.foyer.v1.GetHomeGraphResponse.Home\x12I\n\x06groups\x18\x03 \x03(\x0b\x32\x39.google.internal.home.foyer.v1.GetHomeGraphResponse.Group\x12P\n\nroom_types\x18\x04 \x03(\x0b\x32<.google.internal.home.foyer.v1.GetHomeGraphResponse.RoomType\x12\x0f\n\x07string5\x18\x05 \x01(\t\x12\r\n\x05\x62ool6\x18\x06 \x01(\x08\x12T\n\x0c\x64\x65vice_types\x18\x07 \x03(\x0b\x32>.google.internal.home.foyer.v1.GetHomeGraphResponse.DeviceType\x12V\n\rproject_types\x18\t \x03(\x0b\x32?.google.internal.home.foyer.v1.GetHomeGraphResponse.ProjectType\x12P\n\tmessage11\x18\x0b \x03(\x0b\x32=.google.internal.home.foyer.v1.GetHomeGraphResponse.Message11\x12R\n\x0blinked_apps\x18\x0c \x03(\x0b\x32=.google.internal.home.foyer.v1.GetHomeGraphResponse.LinkedApp\x1a\xc6\'\n\x04Home\x12\x0f\n\x07home_id\x18\x01 \x01(\t\x12\x11\n\thome_name\x18\x02 \x01(\t\x12S\n\x08location\x18\x03 \x01(\x0b\x32\x41.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Location\x12Y\n\x0clinked_users\x18\x04 \x03(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.LinkedUser\x12L\n\x05rooms\x18\x06 \x03(\x0b\x32=.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Room\x12P\n\x07\x64\x65vices\x18\x07 \x03(\x0b\x32?.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device\x12U\n\tmessage11\x18\x0b \x01(\x0b\x32\x42.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message11\x12\x10\n\x08string12\x18\x0c \x01(\t\x12U\n\tmessage13\x18\r \x01(\x0b\x32\x42.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message13\x12\x11\n\tmessage14\x18\x0e \x01(\t\x12U\n\tmessage15\x18\x0f \x01(\x0b\x32\x42.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message15\x1a\xd9\x01\n\x08Location\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x62\n\x0b\x63oordinates\x18\x02 \x01(\x0b\x32M.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Location.Coordinates\x12\x12\n\ntimestamp5\x18\x05 \x01(\x04\x12\x10\n\x08timezone\x18\x06 \x01(\t\x1a\x32\n\x0b\x43oordinates\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x1a#\n\nLinkedUser\x12\x15\n\remail_address\x18\x01 \x01(\t\x1a\x9e\x01\n\x04Room\x12\x0f\n\x07room_id\x18\x01 \x01(\t\x12\x11\n\troom_name\x18\x03 \x01(\t\x12X\n\x08\x63\x61tegory\x18\x04 \x01(\x0b\x32\x46.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Room.Category\x1a\x18\n\x08\x43\x61tegory\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\xbb\x18\n\x06\x44\x65vice\x12_\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32J.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.DeviceInfo\x12\x13\n\x0b\x64\x65vice_name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x06 \x01(\t\x12\x0e\n\x06traits\x18\x07 \x03(\t\x12\x0e\n\x06suffix\x18\n \x01(\t\x12\\\n\tmessage12\x18\x0c \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message12\x12\\\n\tmessage15\x18\x0f \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message15\x12Z\n\x08hardware\x18\x11 \x01(\x0b\x32H.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Hardware\x12\\\n\tmessage18\x18\x12 \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message18\x12\x13\n\x0btimestamp19\x18\x13 \x01(\x04\x12\\\n\tmessage20\x18\x14 \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20\x12\\\n\tmessage25\x18\x19 \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message25\x12`\n\x0clinked_users\x18\x1a \x03(\x0b\x32J.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.LinkedUser\x12\x18\n\x10local_auth_token\x18\x1c \x01(\t\x12U\n\x06states\x18\x1d \x03(\x0b\x32\x45.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.State\x12\\\n\tmessage30\x18\x1e \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message30\x12\\\n\tmessage34\x18" \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message34\x12\r\n\x05num37\x18% \x01(\r\x12\x10\n\x08string41\x18) \x01(\t\x12\x10\n\x08string42\x18* \x01(\t\x1a\xc1\x01\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12h\n\nagent_info\x18\x02 \x01(\x0b\x32T.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.DeviceInfo.AgentInfo\x1a\x36\n\tAgentInfo\x12\x16\n\x0e\x61pi_project_id\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x1aq\n\tMessage12\x12\x0c\n\x04num2\x18\x02 \x01(\r\x12\x0c\n\x04num4\x18\x04 \x01(\r\x12\x0c\n\x04num5\x18\x05 \x01(\r\x12\r\n\x05num37\x18% \x01(\r\x12\r\n\x05num38\x18& \x01(\r\x12\r\n\x05num45\x18- \x01(\r\x12\r\n\x05num46\x18. \x01(\r\x1a\x43\n\tMessage15\x12\x0c\n\x04num1\x18\x01 \x01(\x04\x12\x0c\n\x04num5\x18\x05 \x01(\x04\x12\x0c\n\x04num6\x18\x06 \x01(\x04\x12\x0c\n\x04num7\x18\x07 \x01(\x04\x1a\x19\n\x08Hardware\x12\r\n\x05model\x18\x02 \x01(\t\x1a \n\tMessage18\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x1a\x88\x08\n\tMessage20\x12\x64\n\x08message1\x18\x01 \x03(\x0b\x32R.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1\x1a\x94\x07\n\x08Message1\x12\x0b\n\x03key\x18\x01 \x01(\t\x12g\n\x05value\x18\x02 \x01(\x0b\x32X.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value\x1a\x91\x06\n\x05Value\x12s\n\x08message6\x18\x06 \x01(\x0b\x32\x61.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6\x1a\x92\x05\n\x08Message6\x12|\n\x08message1\x18\x01 \x01(\x0b\x32j.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1\x1a\x87\x04\n\x08Message1\x12\x85\x01\n\x08message5\x18\x05 \x01(\x0b\x32s.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5\x1a\xf2\x02\n\x08Message5\x12\x8e\x01\n\x08message1\x18\x01 \x03(\x0b\x32|.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5.Message1\x1a\xd4\x01\n\x08Message1\x12\x12\n\ncapability\x18\x01 \x01(\t\x12\x98\x01\n\x08message2\x18\x02 \x01(\x0b\x32\x85\x01.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5.Message1.Message2\x1a\x19\n\x08Message2\x12\r\n\x05\x62ool4\x18\x04 \x01(\x08\x1a)\n\tMessage25\x12\r\n\x05\x62ool1\x18\x01 \x01(\x08\x12\r\n\x05\x62ool2\x18\x02 \x01(\x08\x1a#\n\nLinkedUser\x12\x15\n\remail_address\x18\x01 \x01(\t\x1a$\n\x05State\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x1a\xa6\x02\n\tMessage30\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x64\n\x08message2\x18\x02 \x01(\x0b\x32R.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message30.Message2\x1a\xa5\x01\n\x08Message2\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12m\n\x08message2\x18\x02 \x01(\x0b\x32[.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message30.Message2.Message2\x1a\x19\n\x08Message2\x12\r\n\x05\x62ool4\x18\x04 \x01(\x08\x1a\x1a\n\tMessage34\x12\r\n\x05\x62ool1\x18\x01 \x01(\x08\x1a\x1a\n\tMessage11\x12\r\n\x05\x62ool1\x18\x01 \x01(\x08\x1a\xe4\x03\n\tMessage13\x12]\n\x08message1\x18\x01 \x01(\x0b\x32K.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message13.Message1\x12\x14\n\x0c\x64uo_call_url\x18\x02 \x01(\t\x12\x18\n\x10\x64uo_phone_number\x18\x03 \x01(\t\x1a\xc7\x02\n\x08Message1\x12k\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32V.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message13.Message1.DeviceInfo\x1a\xcd\x01\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12t\n\nagent_info\x18\x02 \x01(\x0b\x32`.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message13.Message1.DeviceInfo.AgentInfo\x1a\x36\n\tAgentInfo\x12\x16\n\x0e\x61pi_project_id\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x1a\xbc\x02\n\tMessage15\x12\r\n\x05\x62ool1\x18\x01 \x01(\x08\x12\x0f\n\x07string2\x18\x02 \x01(\t\x12]\n\x08message3\x18\x03 \x03(\x0b\x32K.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message15.Message3\x12\r\n\x05\x62ool4\x18\x04 \x01(\x08\x1a\xa0\x01\n\x08Message3\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12\x66\n\x08message2\x18\x02 \x01(\x0b\x32T.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message15.Message3.Message2\x1a\x1b\n\x08Message2\x12\x0f\n\x07string1\x18\x01 \x01(\t\x1a\x87\x08\n\x05Group\x12Y\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32\x44.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.DeviceInfo\x12\x12\n\ngroup_nmae\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x06 \x01(\t\x12\x0e\n\x06traits\x18\x07 \x01(\t\x12\x0e\n\x06suffix\x18\n \x01(\t\x12V\n\tmessage12\x18\x0c \x01(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.Message12\x12V\n\tmessage15\x18\x0f \x01(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.Message15\x12V\n\tmessage17\x18\x11 \x01(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.Message17\x12V\n\tmessage18\x18\x12 \x01(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.Message18\x12\x13\n\x0btimestamp19\x18\x13 \x01(\x04\x12V\n\tmessage34\x18" \x01(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.Message34\x1a\xa8\x01\n\nDeviceInfo\x12\x62\n\nagent_info\x18\x02 \x01(\x0b\x32N.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.DeviceInfo.AgentInfo\x1a\x36\n\tAgentInfo\x12\x16\n\x0e\x61pi_project_id\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x1aI\n\tMessage12\x12\r\n\x05\x62ool3\x18\x03 \x01(\x08\x12\r\n\x05\x62ool4\x18\x04 \x01(\x08\x12\x0e\n\x06\x62ool37\x18% \x01(\x08\x12\x0e\n\x06\x62ool38\x18& \x01(\x08\x1a\x38\n\tMessage15\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12\x0c\n\x04num5\x18\x05 \x01(\x04\x12\x0c\n\x04num6\x18\x06 \x01(\r\x1a \n\tMessage17\x12\x13\n\x0bgroup_model\x18\x02 \x01(\t\x1a\x1f\n\tMessage18\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x1a\x1a\n\tMessage34\x12\r\n\x05\x62ool1\x18\x01 \x01(\x08\x1a&\n\x08RoomType\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a(\n\nDeviceType\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a)\n\x0bProjectType\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a\x8d\x01\n\tMessage11\x12\x0c\n\x04name\x18\x01 \x01(\t\x12X\n\x08message2\x18\x02 \x01(\x0b\x32\x46.google.internal.home.foyer.v1.GetHomeGraphResponse.Message11.Message2\x1a\x18\n\x08Message2\x12\x0c\n\x04num2\x18\x02 \x01(\r\x1aW\n\tLinkedApp\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12\x0f\n\x07string2\x18\x02 \x01(\t\x12\x0c\n\x04num3\x18\x03 \x01(\r\x12\x0c\n\x04num4\x18\x04 \x01(\r\x12\x0c\n\x04num5\x18\x05 \x01(\r"\xdb\x02\n!GetAssistantDeviceSettingsRequest\x12`\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32K.google.internal.home.foyer.v1.GetAssistantDeviceSettingsRequest.DeviceInfo\x12\x0f\n\x07string2\x18\x02 \x01(\t\x1a\xc2\x01\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12i\n\nagent_info\x18\x02 \x01(\x0b\x32U.google.internal.home.foyer.v1.GetAssistantDeviceSettingsRequest.DeviceInfo.AgentInfo\x1a\x36\n\tAgentInfo\x12\x16\n\x0e\x61pi_project_id\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t"\xe6\x01\n"GetAssistantDeviceSettingsResponse\x12\\\n\x08message1\x18\x01 \x01(\x0b\x32J.google.internal.home.foyer.v1.GetAssistantDeviceSettingsResponse.Message1\x1a\x62\n\x08Message1\x12\x0c\n\x04num1\x18\x01 \x01(\r\x12\x0c\n\x04num2\x18\x02 \x01(\r\x12\x0c\n\x04num4\x18\x04 \x01(\r\x12\x0c\n\x04num5\x18\x05 \x01(\r\x12\x0c\n\x04num6\x18\x06 \x01(\r\x12\x10\n\x08string10\x18\n \x01(\t"\xa3\x05\n$UpdateAssistantDeviceSettingsRequest\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12\x63\n\x0b\x64\x65vice_info\x18\x02 \x01(\x0b\x32N.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsRequest.DeviceInfo\x12\x63\n\x0bupdate_data\x18\x03 \x01(\x0b\x32N.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsRequest.UpdateData\x1a\xc5\x01\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12l\n\nagent_info\x18\x02 \x01(\x0b\x32X.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsRequest.DeviceInfo.AgentInfo\x1a\x36\n\tAgentInfo\x12\x16\n\x0e\x61pi_project_id\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x1a\xd7\x01\n\nUpdateData\x12i\n\x08message1\x18\x01 \x01(\x0b\x32W.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsRequest.UpdateData.Message1\x1a^\n\x08Message1\x12\x1f\n\x17youtube_restricted_mode\x18\x04 \x01(\r\x12!\n\x19youtube_tv_content_filter\x18\x05 \x01(\r\x12\x0e\n\x06locale\x18\n \x01(\t"8\n%UpdateAssistantDeviceSettingsResponse\x12\x0f\n\x07string1\x18\x01 \x01(\t2\xa8\x01\n\x12HomeControlService\x12\x91\x01\n\x14GetAssistantRoutines\x12:.google.internal.home.foyer.v1.GetAssistantRoutinesRequest\x1a;.google.internal.home.foyer.v1.GetAssistantRoutinesResponse0\x01\x32\x8c\x01\n\x11StructuresService\x12w\n\x0cGetHomeGraph\x12\x32.google.internal.home.foyer.v1.GetHomeGraphRequest\x1a\x33.google.internal.home.foyer.v1.GetHomeGraphResponse2\xe9\x02\n\x12HomeDevicesService\x12\xa3\x01\n\x1aGetAssistantDeviceSettings\x12@.google.internal.home.foyer.v1.GetAssistantDeviceSettingsRequest\x1a\x41.google.internal.home.foyer.v1.GetAssistantDeviceSettingsResponse0\x01\x12\xac\x01\n\x1dUpdateAssistantDeviceSettings\x12\x43.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsRequest\x1a\x44.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsResponse0\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "ghome_foyer_api.api_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_GETASSISTANTROUTINESREQUEST"]._serialized_start = 60
    _globals["_GETASSISTANTROUTINESREQUEST"]._serialized_end = 89
    _globals["_GETASSISTANTROUTINESRESPONSE"]._serialized_start = 92
    _globals["_GETASSISTANTROUTINESRESPONSE"]._serialized_end = 976
    _globals["_GETASSISTANTROUTINESRESPONSE_PART1"]._serialized_start = 283
    _globals["_GETASSISTANTROUTINESRESPONSE_PART1"]._serialized_end = 933
    _globals["_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW"]._serialized_start = 443
    _globals["_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW"]._serialized_end = 933
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1"
    ]._serialized_start = 569
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1"
    ]._serialized_end = 933
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1_WF_SUB1_SUB1"
    ]._serialized_start = 713
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1_WF_SUB1_SUB1"
    ]._serialized_end = 933
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1_WF_SUB1_SUB1_ROUTINE"
    ]._serialized_start = 868
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1_WF_SUB1_SUB1_ROUTINE"
    ]._serialized_end = 933
    _globals["_GETASSISTANTROUTINESRESPONSE_PART2"]._serialized_start = 935
    _globals["_GETASSISTANTROUTINESRESPONSE_PART2"]._serialized_end = 976
    _globals["_GETHOMEGRAPHREQUEST"]._serialized_start = 978
    _globals["_GETHOMEGRAPHREQUEST"]._serialized_end = 1030
    _globals["_GETHOMEGRAPHRESPONSE"]._serialized_start = 1033
    _globals["_GETHOMEGRAPHRESPONSE"]._serialized_end = 8133
    _globals["_GETHOMEGRAPHRESPONSE_HOME"]._serialized_start = 1679
    _globals["_GETHOMEGRAPHRESPONSE_HOME"]._serialized_end = 6741
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LOCATION"]._serialized_start = 2358
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LOCATION"]._serialized_end = 2575
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LOCATION_COORDINATES"]._serialized_start = 2525
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LOCATION_COORDINATES"]._serialized_end = 2575
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LINKEDUSER"]._serialized_start = 2577
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LINKEDUSER"]._serialized_end = 2612
    _globals["_GETHOMEGRAPHRESPONSE_HOME_ROOM"]._serialized_start = 2615
    _globals["_GETHOMEGRAPHRESPONSE_HOME_ROOM"]._serialized_end = 2773
    _globals["_GETHOMEGRAPHRESPONSE_HOME_ROOM_CATEGORY"]._serialized_start = 2749
    _globals["_GETHOMEGRAPHRESPONSE_HOME_ROOM_CATEGORY"]._serialized_end = 2773
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE"]._serialized_start = 2776
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE"]._serialized_end = 5907
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_DEVICEINFO"]._serialized_start = 3991
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_DEVICEINFO"]._serialized_end = 4184
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_DEVICEINFO_AGENTINFO"
    ]._serialized_start = 4130
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_DEVICEINFO_AGENTINFO"
    ]._serialized_end = 4184
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE12"]._serialized_start = 4186
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE12"]._serialized_end = 4299
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE15"]._serialized_start = 4301
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE15"]._serialized_end = 4368
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_HARDWARE"]._serialized_start = 4370
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_HARDWARE"]._serialized_end = 4395
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE18"]._serialized_start = 4397
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE18"]._serialized_end = 4429
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20"]._serialized_start = 4432
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20"]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1"
    ]._serialized_start = 4548
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE"
    ]._serialized_start = 4679
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6"
    ]._serialized_start = 4806
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1"
    ]._serialized_start = 4945
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5"
    ]._serialized_start = 5094
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5_MESSAGE1"
    ]._serialized_start = 5252
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5_MESSAGE1"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5_MESSAGE1_MESSAGE2"
    ]._serialized_start = 5439
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5_MESSAGE1_MESSAGE2"
    ]._serialized_end = 5464
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE25"]._serialized_start = 5466
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE25"]._serialized_end = 5507
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_LINKEDUSER"]._serialized_start = 2577
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_LINKEDUSER"]._serialized_end = 2612
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_STATE"]._serialized_start = 5546
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_STATE"]._serialized_end = 5582
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30"]._serialized_start = 5585
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30"]._serialized_end = 5879
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30_MESSAGE2"
    ]._serialized_start = 5714
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30_MESSAGE2"
    ]._serialized_end = 5879
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30_MESSAGE2_MESSAGE2"
    ]._serialized_start = 5439
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30_MESSAGE2_MESSAGE2"
    ]._serialized_end = 5464
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE34"]._serialized_start = 5881
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE34"]._serialized_end = 5907
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE11"]._serialized_start = 5909
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE11"]._serialized_end = 5935
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13"]._serialized_start = 5938
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13"]._serialized_end = 6422
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1"]._serialized_start = 6095
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1"]._serialized_end = 6422
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1_DEVICEINFO"
    ]._serialized_start = 6217
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1_DEVICEINFO"
    ]._serialized_end = 6422
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1_DEVICEINFO_AGENTINFO"
    ]._serialized_start = 4130
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1_DEVICEINFO_AGENTINFO"
    ]._serialized_end = 4184
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15"]._serialized_start = 6425
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15"]._serialized_end = 6741
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15_MESSAGE3"]._serialized_start = 6581
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15_MESSAGE3"]._serialized_end = 6741
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15_MESSAGE3_MESSAGE2"
    ]._serialized_start = 5714
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15_MESSAGE3_MESSAGE2"
    ]._serialized_end = 5741
    _globals["_GETHOMEGRAPHRESPONSE_GROUP"]._serialized_start = 6744
    _globals["_GETHOMEGRAPHRESPONSE_GROUP"]._serialized_end = 7775
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_DEVICEINFO"]._serialized_start = 7379
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_DEVICEINFO"]._serialized_end = 7547
    _globals[
        "_GETHOMEGRAPHRESPONSE_GROUP_DEVICEINFO_AGENTINFO"
    ]._serialized_start = 4130
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_DEVICEINFO_AGENTINFO"]._serialized_end = 4184
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE12"]._serialized_start = 7549
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE12"]._serialized_end = 7622
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE15"]._serialized_start = 7624
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE15"]._serialized_end = 7680
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE17"]._serialized_start = 7682
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE17"]._serialized_end = 7714
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE18"]._serialized_start = 7716
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE18"]._serialized_end = 7747
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE34"]._serialized_start = 5881
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE34"]._serialized_end = 5907
    _globals["_GETHOMEGRAPHRESPONSE_ROOMTYPE"]._serialized_start = 7777
    _globals["_GETHOMEGRAPHRESPONSE_ROOMTYPE"]._serialized_end = 7815
    _globals["_GETHOMEGRAPHRESPONSE_DEVICETYPE"]._serialized_start = 7817
    _globals["_GETHOMEGRAPHRESPONSE_DEVICETYPE"]._serialized_end = 7857
    _globals["_GETHOMEGRAPHRESPONSE_PROJECTTYPE"]._serialized_start = 7859
    _globals["_GETHOMEGRAPHRESPONSE_PROJECTTYPE"]._serialized_end = 7900
    _globals["_GETHOMEGRAPHRESPONSE_MESSAGE11"]._serialized_start = 7903
    _globals["_GETHOMEGRAPHRESPONSE_MESSAGE11"]._serialized_end = 8044
    _globals["_GETHOMEGRAPHRESPONSE_MESSAGE11_MESSAGE2"]._serialized_start = 8020
    _globals["_GETHOMEGRAPHRESPONSE_MESSAGE11_MESSAGE2"]._serialized_end = 8044
    _globals["_GETHOMEGRAPHRESPONSE_LINKEDAPP"]._serialized_start = 8046
    _globals["_GETHOMEGRAPHRESPONSE_LINKEDAPP"]._serialized_end = 8133
    _globals["_GETASSISTANTDEVICESETTINGSREQUEST"]._serialized_start = 8136
    _globals["_GETASSISTANTDEVICESETTINGSREQUEST"]._serialized_end = 8483
    _globals["_GETASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO"]._serialized_start = 8289
    _globals["_GETASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO"]._serialized_end = 8483
    _globals[
        "_GETASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO_AGENTINFO"
    ]._serialized_start = 4130
    _globals[
        "_GETASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO_AGENTINFO"
    ]._serialized_end = 4184
    _globals["_GETASSISTANTDEVICESETTINGSRESPONSE"]._serialized_start = 8486
    _globals["_GETASSISTANTDEVICESETTINGSRESPONSE"]._serialized_end = 8716
    _globals["_GETASSISTANTDEVICESETTINGSRESPONSE_MESSAGE1"]._serialized_start = 8618
    _globals["_GETASSISTANTDEVICESETTINGSRESPONSE_MESSAGE1"]._serialized_end = 8716
    _globals["_UPDATEASSISTANTDEVICESETTINGSREQUEST"]._serialized_start = 8719
    _globals["_UPDATEASSISTANTDEVICESETTINGSREQUEST"]._serialized_end = 9394
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO"
    ]._serialized_start = 8979
    _globals["_UPDATEASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO"]._serialized_end = 9176
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO_AGENTINFO"
    ]._serialized_start = 4130
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO_AGENTINFO"
    ]._serialized_end = 4184
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_UPDATEDATA"
    ]._serialized_start = 9179
    _globals["_UPDATEASSISTANTDEVICESETTINGSREQUEST_UPDATEDATA"]._serialized_end = 9394
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_UPDATEDATA_MESSAGE1"
    ]._serialized_start = 9300
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_UPDATEDATA_MESSAGE1"
    ]._serialized_end = 9394
    _globals["_UPDATEASSISTANTDEVICESETTINGSRESPONSE"]._serialized_start = 9396
    _globals["_UPDATEASSISTANTDEVICESETTINGSRESPONSE"]._serialized_end = 9452
    _globals["_HOMECONTROLSERVICE"]._serialized_start = 9455
    _globals["_HOMECONTROLSERVICE"]._serialized_end = 9623
    _globals["_STRUCTURESSERVICE"]._serialized_start = 9626
    _globals["_STRUCTURESSERVICE"]._serialized_end = 9766
    _globals["_HOMEDEVICESSERVICE"]._serialized_start = 9769
    _globals["_HOMEDEVICESSERVICE"]._serialized_end = 10130
# @@protoc_insertion_point(module_scope)
